@@ -1,5 +1,4 @@
 import dataclasses
-import functools
 import io
 import json
 import logging
@@ -13,7 +12,6 @@ from collections import namedtuple, defaultdict
 from datetime import datetime
 from hashlib import md5
 from io import BytesIO, StringIO
-from multiprocessing.pool import ThreadPool
 
 import tqdm
 
@@ -84,8 +82,12 @@ class BaseClassificationDatabasePacker(object):
 
         self.meta_data = {
             'packed': datetime.now().strftime('%c'),
+            'model_type': kwargs.get('model_type', 'facenet'),
+            'model_codename': kwargs.get('model_codename'),
             'sdk_version': rebotics_sdk.__version__,
-            'packer_version': self.version
+            'packer_version': self.version,
+            'core_version': kwargs.get('core_version'),
+            'fvm_version': kwargs.get('fvm_version')
         }
         self.zip_io = None
 
