@@ -42,6 +42,7 @@ def api(ctx, format, verbose, config, role):
     """
     process_role(ctx, role, 'admin')
     ctx.obj = ReboticsCLIContext(
+        'admin',
         role,
         format,
         verbose,
@@ -274,8 +275,20 @@ def set_retailer_url(ctx, retailer, url):
 @click.option('-l', '--labels', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @click.option('-f', '--features', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @click.option('-c', '--check-duplicates', is_flag=True, help="MD5 checker simple")
+@click.option('-m', '--model-type', type=str, default='facenet')
+@click.option('-n', '--model-codename', type=str)
 @pass_rebotics_context
-def pack_and_import_classification_db(ctx, retailer, model, images, labels, features, check_duplicates):
+def pack_and_import_classification_db(
+    ctx,
+    retailer,
+    model,
+    images,
+    labels,
+    features,
+    check_duplicates,
+    model_type,
+    model_codename,
+):
     """Pack classification database to single .rcdb file and import it to the Rebotics Admin
 
 \b
@@ -300,7 +313,13 @@ admin import_classification_db --retailer delta --model test_code classification
                        "model: {}\n"
                        "extension: {}".format(retailer, model, ClassificationDatabasePacker))
 
-        packer = ClassificationDatabasePacker(destination=None, progress_bar=True, check_duplicates=check_duplicates)
+        packer = ClassificationDatabasePacker(
+            destination=None,
+            progress_bar=True,
+            check_duplicates=check_duplicates,
+            model_type=model_type,
+            model_codename=model_codename,
+        )
         if ctx.verbose:
             click.echo("Packing from provided values: \n"
                        "labels: {labels} \n"
@@ -387,9 +406,11 @@ def handle_duplicates(ctx, duplicates):
 @click.option('-l', '--labels', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @click.option('-f', '--features', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @click.option('-c', '--check-duplicates', is_flag=True, help="MD5 checker simple")
+@click.option('-m', '--model-type', type=str, default='facenet')
+@click.option('-n', '--model-codename', type=str)
 @click.argument('target', type=click.Path(exists=False, file_okay=True, dir_okay=True), default='.')
 @pass_rebotics_context
-def pack_classification_db(ctx, images, labels, features, target, check_duplicates):
+def pack_classification_db(ctx, images, labels, features, target, check_duplicates, model_type, model_codename):
     """Pack classification database to single .rcdb file
 
 \b
@@ -413,7 +434,9 @@ db/
     packer = ClassificationDatabasePacker(
         destination=target,
         progress_bar=True,
-        check_duplicates=check_duplicates
+        check_duplicates=check_duplicates,
+        model_type=model_type,
+        model_codename=model_codename,
     )
     if ctx.verbose:
         click.echo("Packing from provided values: \n"
