@@ -32,3 +32,19 @@ class AuthenticatedRoleProvider:
             PROVIDER_NAME_TO_CLASS[provider_name]
         )
         return config_provider.get_provider(role)
+
+
+def get_provider(provider_name, role):
+    """
+    get authenticated provider for given role.
+    Intendent to be used in scripts provided by the rebotics team.
+
+    :param provider_name: name of the provider. One of: retailer, cvat, admin, dataset, fvm, hawkeye
+    :param role: role to use for authentication
+
+    General usage:
+    >>> from rebotics_sdk import get_provider
+    >>> admin = get_provider('admin', 'r3dev')
+    >>> admin.version()
+    """
+    return AuthenticatedRoleProvider().get_provider(provider_name, role)
