@@ -2,16 +2,17 @@ import csv
 import json
 import logging
 import os
-import pathlib
-import shutil
 import webbrowser
+from concurrent.futures import ThreadPoolExecutor
 from copy import copy
 from datetime import datetime
+from functools import partial
 from multiprocessing import Pool
 from pathlib import Path
 
 import click
 import pandas as pd
+from click import get_current_context
 from tqdm import tqdm
 
 from rebotics_sdk import utils
@@ -23,6 +24,7 @@ from .tasks import task_create_processing_action_for_image, upload_preview_task,
 from .utils import ReboticsCLIContext, pass_rebotics_context, app_dir, process_role, read_saved_role, task_runner, \
     download_file_from_dict, guess_input_type
 from ..advanced import remote_loaders
+from ..constants import CVAT_EXPORT_WORKSPACE
 from ..providers import RetailerProvider, ProviderHTTPClientException
 from ..utils import mkdir_p, get_filename_from_url, download_file
 
@@ -43,6 +45,7 @@ def api(ctx, format, verbose, config, role):
     process_role(ctx, role, 'retailer')
 
     ctx.obj = ReboticsCLIContext(
+        'retailer',
         role,
         format,
         verbose,
@@ -128,19 +131,21 @@ def export_to_dataset(ctx, processing_ids, batch_size):
 
 @api.command()
 @click.argument('processing_ids', required=True, nargs=-1, type=click.INT)
-@click.option('-q', '--image-quality', type=int, default=70,
-              help="Jpeg image quality between 0 and 100. Default is 70.")
+@click.option('-q', '--image-quality', type=int, default=80,
+              help="Jpeg image quality between 0 and 100. Default is 80.")
 @click.option('-s', '--segment-size', type=int, default=20,
               help="Number of images in job. Set 0 to not split task into jobs.")
+@click.option('-w', '--workspace', type=str, default=CVAT_EXPORT_WORKSPACE,
+              help='Workspace (organization) name in CVAT. Case sensitive.')
 @pass_rebotics_context
-def export_to_cvat(ctx, processing_ids, image_quality, segment_size):
+def export_to_cvat(ctx, processing_ids, image_quality, segment_size, workspace):
     if ctx.verbose:
         click.echo('Exporting scans to CVAT: {}'.format(processing_ids), err=True)
 
     try:
         if ctx.verbose:
             click.echo('Sending request...')
-        response = ctx.provider.export_to_cvat(processing_ids, image_quality, segment_size)
+        response = ctx.provider.export_to_cvat(processing_ids, image_quality, segment_size, workspace)
         click.echo('Queued to export to CVAT: {}'.format(response))
     except ProviderHTTPClientException as exc:
         if ctx.verbose:
@@ -523,7 +528,6 @@ def task_upload_and_notify_request(task_def):
 @click.option('-t', '--input_type')
 @pass_rebotics_context
 def upload_processing_files(ctx, files, concurrency, input_type):
-
     task_defs = []
 
     for file in tqdm(files, 'Getting S3 pre-signed post', leave=False):
@@ -560,11 +564,21 @@ def upload_processing_files(ctx, files, concurrency, input_type):
 @pass_rebotics_context
 @click.pass_context
 def processing_action(click_context, ctx, processing_id):
-    """Returns processing action by processing_id."""
+    """Command group for scans in a format of single entry or list or range.
+    Supports following formats:
+
+        1. 1-10
+
+        2. 1,2,3,4,5
+
+        3. 1,2,3-5,6,7,8-10
+    """
     try:
         processing_ids = utils.parse_id_range_string(processing_id)
     except ValueError as exc:
-        raise click.ClickException(exc)
+        ctx.verbose_log(exc)
+        click_context.exit(1)
+        return
 
     setattr(ctx, 'processing_id', processing_ids[0])
     setattr(ctx, 'processing_id_string', processing_id)
@@ -718,19 +732,6 @@ def processing_action_copy(ctx, store):
         click.echo('Failed to create processing action: %s' % exc)
 
 
-@processing_action.command(name='notify-oos')
-@click.option('-f', '--force', is_flag=True, default=False)
-@pass_rebotics_context
-def processing_action_notify_oss_report_ready(ctx, force):
-    try:
-        result = ctx.provider.send_oos_notification(ctx.processing_id, force)
-        ctx.format_result(result)
-    except ProviderHTTPClientException as exc:
-        if ctx.verbose:
-            logger.exception(exc)
-        click.echo('Failed to notify OOS report ready. %s' % exc)
-
-
 @processing_action.command(name="report-image")
 @click.option('-l', '--label', type=click.Choice([
     "unique_id",
@@ -741,6 +742,7 @@ def processing_action_notify_oss_report_ready(ctx, force):
 @click.option('-t', '--target', type=click.Path(), default='.')
 @pass_rebotics_context
 def processing_action_report_image(ctx, label, target):
+    """Download and annotated report image locally."""
     image_url = ctx.provider.build_url("/api/v4/processing/actions/{id}/report_image/".format(id=ctx.processing_id))
     if ctx.verbose:
         click.echo("URL: {}".format(image_url))
@@ -875,6 +877,7 @@ def processing_action_realogram_report(ctx, concurrency, drop_duplicates, target
                                                                                     ' the reverse planogram file will be saved')
 @pass_rebotics_context
 def reverse_planogram(ctx, target):
+    """Get CSV representation of the realogram in a reverse planogram format."""
     if ctx.verbose:
         click.echo("Downloading scan with id #{}".format(ctx.processing_id))
 
@@ -893,6 +896,7 @@ def reverse_planogram(ctx, target):
               help="Save into file, if none provided, will print to STDOUT")
 @pass_rebotics_context
 def processing_spacial(ctx, target):
+    """Download spacial result. Doesn't support multiple processing ids"""
     data = ctx.provider.get_spacial_data(ctx.processing_id)
 
     if target is None:
@@ -908,6 +912,82 @@ def processing_spacial(ctx, target):
     click.echo("Saved into {}".format(target))
 
 
+def download_processing_core_result(scan_id, ctx, target):
+    scan_data = ctx.provider.get_scan_info(scan_id)  # processing_id is the scan id
+
+    ctx.verbose_log(f"Scan data: {scan_data}")
+    processing_action_id = scan_data['active_processing_action']
+    task_list = ctx.provider.get_task_list_for_action(processing_action_id)
+
+    ctx.verbose_log(f"Number of tasks are: {len(task_list)}")
+
+    for i, task in enumerate(task_list):
+        try:
+            core_result = ctx.provider.get_core_result(processing_action_id, task['id'])
+        except json.JSONDecodeError:
+            ctx.verbose_log(f"Task {task['id']} has no core result...")
+            continue
+
+        if not core_result:
+            click.echo("No core result for this scan")
+            return
+
+        if target is None:
+            # printing to STDOUT
+            click.echo(json.dumps(core_result, indent=2))
+            return
+
+        target = Path(target)
+        if target.is_dir():
+            if i == 0:
+                target /= "core_result_{}_{}.json".format(scan_id, datetime.now().strftime("%Y-%m-%d"))
+            if i > 0:
+                target /= "core_result_{}_{}_{}.json".format(scan_id, i, datetime.now().strftime("%Y-%m-%d"))
+        else:
+            # because multiple processing action tasks can be downloaded, we need to append the task id to the file name
+            target = Path(str(target).replace('.json', f'_{task["id"]}.json'))
+
+        with open(target, 'w') as fout:
+            json.dump(core_result, fout, indent=2)
+        click.echo(f"Saved into {target.absolute()}")
+
+
+@processing_action.command('core-result')
+@click.option('-t', '--target', type=click.Path(file_okay=True, dir_okay=True), default=None,
+              help="Save into file, if none provided, will print to STDOUT")
+@click.option('-c', '--concurrency', default=4, help='Define how many parallel workers will be used to access API')
+@pass_rebotics_context
+def processing_core_result(ctx, target, concurrency):
+    """Download core result for scan and save it into json file"""
+    click_ctx = get_current_context()
+
+    if target is not None:
+        target = Path(target)
+        if not target.is_dir():
+            if target.suffix != '.json':
+                click.echo("Target must be a directory or a json file")
+                click_ctx.exit(1)
+                return
+
+            if len(ctx.processing_id_list) > 1:
+                click.echo("Target must be a directory if you want to download in a batch")
+                click_ctx.exit(1)
+                return
+
+    if len(ctx.processing_id_list) == 1:
+        download_processing_core_result(ctx.processing_id, ctx, target)
+        return
+
+    ctx.verbose_log("Downloading core result for multiple scans")
+    with ThreadPoolExecutor(max_workers=min(concurrency, len(ctx.processing_id_list))) as executor:
+        for _ in executor.map(
+            partial(download_processing_core_result, ctx=ctx, target=target),
+            ctx.processing_id_list
+        ):
+            pass
+    executor.shutdown(wait=True)
+
+
 @api.group(name='fv')
 def feature_vectors():
     """
