@@ -78,7 +78,8 @@ class ReboticsScriptsConfiguration(DumpableConfiguration):
 class ReboticsCLIContext(object):
     configuration_class = ReboticsScriptsConfiguration
 
-    def __init__(self, role, format, verbose, config_path, provider_class):
+    def __init__(self, command, role, format, verbose, config_path, provider_class):
+        self.command = command
         self.role = role
         self.format = format
         self.verbose = verbose
@@ -93,8 +94,8 @@ class ReboticsCLIContext(object):
         provider = self.config_provider.get_provider(self.role)
 
         if provider is None:
-            raise click.ClickException('Role {0} is not configured.\n'
-                                       'Run: \n<command> -r {0} configure'.format(self.role))
+            raise click.ClickException(f'Role {self.role} is not configured.\n'
+                                       f'Run: \n{self.command} -r {self.role} configure')
         return provider
 
     def update_configuration(self, **configuration):
@@ -252,12 +253,12 @@ def refresh_url(refresh_url, segmentation_per_image):
 
 
 def save_masks(root_folder, urls):
-        path_to_save_masks = root_folder / 'all_masks'
-        path_to_save_masks.mkdir(parents=True, exist_ok=True)
+    path_to_save_masks = root_folder / 'all_masks'
+    path_to_save_masks.mkdir(parents=True, exist_ok=True)
 
-        list_with_downloaded_mask = [
-            [url, path_to_save_masks / str(urlparse(unquote(url)).path).lstrip('/').split('/')[-1]]
-            for url in urls
-        ]
+    list_with_downloaded_mask = [
+        [url, path_to_save_masks / str(urlparse(unquote(url)).path).lstrip('/').split('/')[-1]]
+        for url in urls
+    ]
 
-        downloads_with_threads(list_with_downloaded_mask, concurrency=len(list_with_downloaded_mask))
+    downloads_with_threads(list_with_downloaded_mask, concurrency=len(list_with_downloaded_mask))
