@@ -5,6 +5,7 @@ import six
 from rebotics_sdk.providers.utils import hash_file, accept_file
 from .base import ReboticsBaseProvider, remote_service, PageResult, UniqueRequestProxy
 from ..advanced.flows import FeatureVectorFlow
+from ..constants import CVAT_EXPORT_WORKSPACE
 
 
 class RetailerProvider(ReboticsBaseProvider):
@@ -268,7 +269,7 @@ class RetailerProvider(ReboticsBaseProvider):
         data = self.session.get(params=params)
         return PageResult(data)
 
-    @remote_service('api/v4/imports/planogram/assign/')
+    @remote_service('/api/v4/imports/planogram/assign/')
     def assign_planogram_with_file(self, assign_file, deactivate_old_planograms=False, **kwargs):
 
         file_io = None
@@ -282,7 +283,7 @@ class RetailerProvider(ReboticsBaseProvider):
         file_io.close()
         return result
 
-    @remote_service('api/v4/imports/planogram/')
+    @remote_service('/api/v4/imports/planogram/')
     def import_planogram(
         self,
         planogram_file, title, description='',
@@ -357,7 +358,7 @@ class RetailerProvider(ReboticsBaseProvider):
 
         return response
 
-    @remote_service('api/v4/imports/planogram-assign-file/')
+    @remote_service('/api/v4/imports/planogram-assign-file/')
     def assign_planogram(self, assign_file, deactivate=False, **kwargs):
         """
         Uploads an assign planogram file to retailer. Be careful to upload it.
@@ -378,27 +379,27 @@ class RetailerProvider(ReboticsBaseProvider):
         file_io.close()
         return response
 
-    @remote_service('api/v4/store_aisles/{store_id}')
+    @remote_service('/api/v4/store_aisles/{store_id}')
     def get_store_aisles(self, store_id, **kwargs):
         return self.session.get(store_id=store_id)
 
-    @remote_service('api/v4/stores/')
+    @remote_service('/api/v4/stores/')
     def get_stores(self, **kwargs):
         return self.session.get()
 
-    @remote_service('api/v4/processing_aisles/{processing_id}/')
+    @remote_service('/api/v4/processing_aisles/{processing_id}/')
     def get_processing_aisles(self, processing_id, **kwargs):
         return self.session.get(processing_id=processing_id)
 
-    @remote_service('api/v4/users/')
+    @remote_service('/api/v4/users/')
     def user_list(self, **kwargs):
         return self.session.get()
 
-    @remote_service('api/v4/users/{username}/subscriptions/')
+    @remote_service('/api/v4/users/{username}/subscriptions/')
     def user_subscriptions(self, username, **kwargs):
         return self.session.get(username=username)
 
-    @remote_service('api/v4/users/{username}/subscriptions/')
+    @remote_service('/api/v4/users/{username}/subscriptions/')
     def user_subscriptions_create(self, username, store, aisle, section, **kwargs):
         return self.session.post(
             username=username,
@@ -409,7 +410,7 @@ class RetailerProvider(ReboticsBaseProvider):
             }
         )
 
-    @remote_service('api/v1/master-data/file-upload/')
+    @remote_service('/api/v1/master-data/file-upload/')
     def v1_upload_file(self, file, **kwargs):
         return self.session.post(
             data={
@@ -420,7 +421,7 @@ class RetailerProvider(ReboticsBaseProvider):
             }
         )
 
-    @remote_service('api/v1/master-data/products/{product_id}/images/')
+    @remote_service('/api/v1/master-data/products/{product_id}/images/')
     def v1_upload_preview(self, product_id, image_id, **kwargs):
         return self.session.post(
             product_id=product_id,
@@ -428,24 +429,26 @@ class RetailerProvider(ReboticsBaseProvider):
                 'image': image_id
             }, content_type='application/json')
 
-    @remote_service('api/v4/processing/actions/{id}/spacial')
+    @remote_service('/api/v4/processing/actions/{id}/spacial')
     def get_spacial_data(self, scan_id, **kwargs):
         """Can yield permission error. Internal usage intended"""
         return self.session.get(id=scan_id)
 
-    @remote_service('api/v4/processing/actions/export-to-dataset/')
+    @remote_service('/api/v4/processing/actions/export-to-dataset/')
     def export_to_dataset(self, scan_ids, batch_size=5, **kwargs):
         return self.session.post(json={
             'scans': sorted(list(set(scan_ids))),
             'batch_size': batch_size,
         })
 
-    @remote_service('api/v4/processing/actions/export-to-cvat/')
-    def export_to_cvat(self, scan_ids, image_quality=70, segment_size=20, **kwargs):
+    @remote_service('/api/v4/processing/actions/export-to-cvat/')
+    def export_to_cvat(self, scan_ids, image_quality=80, segment_size=20,
+                       workspace=CVAT_EXPORT_WORKSPACE, **kwargs):
         return self.session.post(json={
             'scans': sorted(list(set(scan_ids))),
             'image_quality': image_quality,
             'segment_size': segment_size,
+            'workspace': workspace,
         })
 
     @remote_service('/api/v1/rebotics/rpc/export-feature-vector/')
@@ -500,3 +503,17 @@ class RetailerProvider(ReboticsBaseProvider):
                 _validate_field(entry, expected_key, conf)
 
         return self.session.post(json=items)
+
+    @remote_service('/api/v1/realograms/actions/{action_id}/tasks/{task_id}/core-result/')
+    def get_core_result(self, action_id, task_id):
+        return self.session.get(action_id=action_id, task_id=task_id)
+
+    @remote_service('/api/v1/realograms/actions/{action_id}/tasks/')
+    def get_task_list_for_action(self, action_id):
+        return PageResult(
+            self.session.get(action_id=action_id)
+        )
+
+    @remote_service('/api/v1/realograms/scans/{scan_id}/')
+    def get_scan_info(self, scan_id):
+        return self.session.get(scan_id=scan_id)
