@@ -1,8 +1,9 @@
+import json
 import pathlib
 import tempfile
-import requests_mock
 
 import pytest
+import requests_mock
 
 from rebotics_sdk.advanced.packers import ClassificationDatabasePacker, ZipDatabasePacker, \
     DuplicateFeatureVectorsException, VirtualClassificationDatabasePacker
@@ -26,6 +27,22 @@ def test_classification_packing(script_cwd):
         res = packer.pack(labels, features, images_folder)
 
         assert 'test.rcdb' in res
+
+        with packer.zipfile(res, mode='r') as zip_io:
+            meta = json.loads(packer.read_lines(zip_io.read('meta.json').decode('utf-8'))[0])
+
+        expected_keys = [
+            'packed',
+            'model_type',
+            'model_codename',
+            'sdk_version',
+            'packer_version',
+            'core_version',
+            'fvm_version'
+        ]
+        for key in expected_keys:
+            assert key in meta.keys()
+
         assert len(packer.images) == 2
 
         packer = ClassificationDatabasePacker(source=res)
@@ -37,6 +54,9 @@ def test_classification_packing(script_cwd):
         internal_filename = entry.filename
         assert internal_filename == 'image_1.png'
 
+        for key in expected_keys:
+            assert key in packer.meta_data.keys()
+
         # testing if it can be dumped to the FS
         og_file = images_folder / internal_filename
         tmp_file = db_folder / internal_filename
