@@ -11,11 +11,13 @@ class RetailerProviderTestCase(TestCase):
     @patch.object(ProviderRequestProxy, 'post')
     def test_export_to_cvat(self, mock_func: MagicMock):
         scan_ids = [4, 3, 4, 2, 1, 2, 1, 3]
-        image_quality = 80
+        image_quality = 70
         segment_size = 30
-        self.provider.export_to_cvat(scan_ids, image_quality, segment_size)
+        workspace = 'Workspace'
+        self.provider.export_to_cvat(scan_ids, image_quality, segment_size, workspace)
         mock_func.assert_called_once_with(json={
             'scans': [1, 2, 3, 4],
             'image_quality': image_quality,
-            'segment_size': segment_size
+            'segment_size': segment_size,
+            'workspace': workspace,
         })
