@@ -16,8 +16,9 @@ class RetailerProviderTestCase(TestCase):
     @patch.object(RetailerProvider, 'export_to_cvat')
     def test_export_to_cvat(self, export_mock: MagicMock, provider_mock: MagicMock, *args):
         scan_ids = [1, 2, 3]
-        image_quality = 80
+        image_quality = 70
         segment_size = 30
+        workspace = 'Workspace'
         command = 'export-to-cvat'
         provider_mock.return_value = RetailerProvider('https://example.com')
 
@@ -25,10 +26,12 @@ class RetailerProviderTestCase(TestCase):
             command,
             '-q', image_quality,
             '-s', segment_size,
+            '-w', workspace,
             *[str(i) for i in scan_ids]
         ])
         export_mock.assert_called_once_with(
             tuple(scan_ids),
             image_quality,
             segment_size,
+            workspace,
         )
